@@ -356,9 +356,9 @@ static const yysigned_char yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const unsigned short yyrline[] =
 {
-       0,    87,    87,   192,   195,   201,   207,   214,   224,   230,
-     236,   244,   245,   248,   264,   272,   273,   276,   289,   299,
-     300,   303,   328,   329,   332,   336,   342,   343,   346
+       0,    87,    87,   191,   194,   200,   206,   213,   223,   229,
+     235,   243,   244,   247,   263,   271,   272,   275,   288,   298,
+     299,   302,   327,   328,   331,   336,   343,   344,   347
 };
 #endif
 
@@ -1127,7 +1127,7 @@ yyreduce:
 						int flag_count = 0;
 						if (h_joints[i].flag & MD5ANIM_TRANSLATION_X)
 						{
-							baseframe[i].frames[j].position.x = frames[j * anim_header.num_joints + h_joints[i].start_index];	
+							baseframe[i].frames[j].position.x = frames[j * 6 * anim_header.num_joints + h_joints[i].start_index];	
 							flag_count++;
 						}
 						else
@@ -1136,7 +1136,7 @@ yyreduce:
 						}
 						if (h_joints[i].flag & MD5ANIM_TRANSLATION_Y)
 						{
-							baseframe[i].frames[j].position.y = frames[j * anim_header.num_joints + h_joints[i].start_index + flag_count];	
+							baseframe[i].frames[j].position.y = frames[j * 6 * anim_header.num_joints + h_joints[i].start_index + flag_count];	
 							flag_count++;
 						}
 						else
@@ -1145,7 +1145,7 @@ yyreduce:
 						}
 						if (h_joints[i].flag & MD5ANIM_TRANSLATION_Z)
 						{
-							baseframe[i].frames[j].position.z = frames[j * anim_header.num_joints + h_joints[i].start_index + flag_count];	
+							baseframe[i].frames[j].position.z = frames[j * 6 * anim_header.num_joints + h_joints[i].start_index + flag_count];	
 							flag_count++;
 						}
 						else
@@ -1155,7 +1155,7 @@ yyreduce:
 
 						if (h_joints[i].flag & MD5ANIM_ORIENTATION_X)
 						{
-							baseframe[i].frames[j].orientation.x = frames[j * anim_header.num_joints + h_joints[i].start_index + flag_count];	
+							baseframe[i].frames[j].orientation.x = frames[j * 6 * anim_header.num_joints + h_joints[i].start_index + flag_count];	
 							flag_count++;
 						}
 						else
@@ -1164,7 +1164,7 @@ yyreduce:
 						}
 						if (h_joints[i].flag & MD5ANIM_ORIENTATION_Y)
 						{
-							baseframe[i].frames[j].orientation.y = frames[j * anim_header.num_joints + h_joints[i].start_index + flag_count];	
+							baseframe[i].frames[j].orientation.y = frames[j * 6 * anim_header.num_joints + h_joints[i].start_index + flag_count];	
 							flag_count++;
 						}
 						else
@@ -1173,7 +1173,7 @@ yyreduce:
 						}
 						if (h_joints[i].flag & MD5ANIM_ORIENTATION_Z)
 						{
-							baseframe[i].frames[j].orientation.z = frames[j * anim_header.num_joints + h_joints[i].start_index + flag_count];	
+							baseframe[i].frames[j].orientation.z = frames[j * 6 * anim_header.num_joints + h_joints[i].start_index + flag_count];	
 							flag_count++;
 						}
 						else
@@ -1183,10 +1183,9 @@ yyreduce:
 						
 						/*compute and set w component of quateration */
 
-						if (h_joints[i].flag & 56)
+						if (h_joints[i].flag & 56) 
 						{
-							float tmp;
-							tmp = 1.0f - ( baseframe[i].frames[j].orientation.x * baseframe[i].frames[j].orientation.x + baseframe[i].frames[j].orientation.y * baseframe[i].frames[j].orientation.y + baseframe[i].frames[j].orientation.z * baseframe[i].frames[j].orientation.z );
+							float tmp = 1.0f - ( baseframe[i].frames[j].orientation.x * baseframe[i].frames[j].orientation.x + baseframe[i].frames[j].orientation.y * baseframe[i].frames[j].orientation.y + baseframe[i].frames[j].orientation.z * baseframe[i].frames[j].orientation.z );
 							if(tmp > 0.0f)
 								baseframe[i].frames[j].orientation.w = -sqrtf( tmp );
 							else
@@ -1212,21 +1211,21 @@ yyreduce:
     break;
 
   case 4:
-#line 196 "md5anim_parser.y"
+#line 195 "md5anim_parser.y"
     {
 			anim_header.version = yyvsp[0].itype;
  		}
     break;
 
   case 5:
-#line 202 "md5anim_parser.y"
+#line 201 "md5anim_parser.y"
     {
 			anim_header.commandline = (const char*)strdup(yyvsp[0].ctype);
 		}
     break;
 
   case 6:
-#line 208 "md5anim_parser.y"
+#line 207 "md5anim_parser.y"
     {
 			anim_header.num_frames = yyvsp[0].itype;
 			bounds = (MD5_BOUND*)malloc(anim_header.num_frames * sizeof(MD5_BOUND));
@@ -1234,7 +1233,7 @@ yyreduce:
     break;
 
   case 7:
-#line 215 "md5anim_parser.y"
+#line 214 "md5anim_parser.y"
     {
 			anim_header.num_joints = yyvsp[0].itype;
 			baseframe = (MD5ANIM_JOINT*)malloc(anim_header.num_joints * sizeof(MD5ANIM_JOINT));
@@ -1245,21 +1244,21 @@ yyreduce:
     break;
 
   case 8:
-#line 225 "md5anim_parser.y"
+#line 224 "md5anim_parser.y"
     {
 			anim_header.frame_rate = yyvsp[0].itype;
 		}
     break;
 
   case 9:
-#line 231 "md5anim_parser.y"
+#line 230 "md5anim_parser.y"
     {
 			anim_header.num_animated_components = yyvsp[0].itype;
 		}
     break;
 
   case 10:
-#line 237 "md5anim_parser.y"
+#line 236 "md5anim_parser.y"
     {
 			if (count != anim_header.num_joints)
 				MD5ANIM_error("Error: Incorrect number of joints");	
@@ -1268,7 +1267,7 @@ yyreduce:
     break;
 
   case 13:
-#line 249 "md5anim_parser.y"
+#line 248 "md5anim_parser.y"
     {
 			int idx = yyvsp[-2].itype;
 			baseframe[count].name = (const char*)strdup(yyvsp[-3].ctype);
@@ -1285,7 +1284,7 @@ yyreduce:
     break;
 
   case 14:
-#line 265 "md5anim_parser.y"
+#line 264 "md5anim_parser.y"
     {
 			if (count != anim_header.num_frames)
 				MD5ANIM_error("Error: Incorrect number of bounds");	
@@ -1294,7 +1293,7 @@ yyreduce:
     break;
 
   case 17:
-#line 277 "md5anim_parser.y"
+#line 276 "md5anim_parser.y"
     {
 			bounds[count].min.x = yyvsp[-8].ftype;
 			bounds[count].min.y = yyvsp[-7].ftype;
@@ -1308,7 +1307,7 @@ yyreduce:
     break;
 
   case 18:
-#line 290 "md5anim_parser.y"
+#line 289 "md5anim_parser.y"
     {
 			if (count != anim_header.num_joints)
 				MD5ANIM_error("Error: Incorrect number of baseframe joints");	
@@ -1319,7 +1318,7 @@ yyreduce:
     break;
 
   case 21:
-#line 304 "md5anim_parser.y"
+#line 303 "md5anim_parser.y"
     {
 			float tmp,q1,q2,q3;
 
@@ -1345,9 +1344,10 @@ yyreduce:
     break;
 
   case 24:
-#line 333 "md5anim_parser.y"
+#line 332 "md5anim_parser.y"
     {
 			frame_index++;
+			frame_number = 0;
 		}
     break;
 
@@ -1355,13 +1355,14 @@ yyreduce:
 #line 337 "md5anim_parser.y"
     {
 			frame_index++;
+			frame_number = 0;
 		}
     break;
 
   case 28:
-#line 347 "md5anim_parser.y"
+#line 348 "md5anim_parser.y"
     {
-			frames[frame_index * anim_header.num_joints + frame_number] = yyvsp[0].ftype;
+			frames[frame_index * anim_header.num_joints * 6 + frame_number] = yyvsp[0].ftype;
 			frame_number++;
 		}
     break;
@@ -1370,7 +1371,7 @@ yyreduce:
     }
 
 /* Line 1000 of yacc.c.  */
-#line 1374 "md5anim_parser.c"
+#line 1375 "md5anim_parser.c"
 
   yyvsp -= yylen;
   yyssp -= yylen;
@@ -1595,7 +1596,7 @@ yyreturn:
 }
 
 
-#line 353 "md5anim_parser.y"
+#line 354 "md5anim_parser.y"
 
 
 
